<?php
class Settings {
/* Main configuration part */
	/**
	* Set the program version. Should not be changed
	* This setting is required
	* @access private
	* @var string
	*/
	private static $version = "2.1.1";

	/**
	* Set the name of the dreambox. Anything is allowed :P
	* This setting is optional
	* @access private
	* @var string
	*/
	private static $dreamboxName = "Yoshie's Dreambox";

	/**
	* Set the local IP address of your dreambox. Should be an internal IP number or hostname. For best performance, use an IP number.
	* This setting is required
	* @access private
	* @var string
	*/
	private static $dreamboxIP = "";

	/**
	* Set the web port number of your dreambox. Mostly is should be port 80, but some versions have a different portnumber.
	* This setting is required
	* @access private
	* @var int
	*/
	private static $dreamboxWebPort = 80;

	/**
	* Set the username for the dreambox webinterface. Leave empty when no authentication is required.
	* This setting is optional
	* @access private
	* @var string
	*/
	private static $dreamboxUserName = "";

	/**
	* Set the password for the dreambox webinterface. Leave empty when no authentication is required.
	* This setting is optional
	* @access private
	* @var string
	*/
	private static $dreamboxPassword = "";

	/**
	* Set the enigma version of the dreambox. Valid values are enigma1 of enigma2
	* This setting is required
	* @access private
	* @var string
	*/
	private static $dreamboxEnigmaVersion = "";
	
	/**
	* Select true if the dreambox has a second tuner. This is only valid for enigma2 based firmwares
	* This setting is required
	* @access private
	* @var boolean
	*/
	private static $dreamboxDualTuner = true;

	/**
	* The full path to your movies folder on the server. It has to be a local path. 
	*
	* Leave empty to disable this feature.
	* This setting is optional
	*
	* @access private
	* @var string
	*/
	private static $moviesPath = "";

	/**
	* Set the alowed extension for valid movies. Should not be changed
	* This setting is required
	* @access private
	* @var string
	*/
	private static $validMovies = "avi,mkv,mpeg,mpg,mp4,mov";
	
/* Private configuration */

	/**
	* If you want to make Dreambox Restream private, set the variable below to 1 and set the username and password
	* Set to false to make Dreambox Restream plublic
	* This setting is optional
	*/
	private static $privateModus = false;
	
	private static $privateModusUsername = "";
	
	private static $privateModusPassword = "";

/* VLC configuration */

	/**
	* Set the location of the VLC server executable. At least set the value that is corresponding with your 
	* operating system where the PHP code is running. The default settings should be working for 90% of the time.
	* This setting is required
	* @access private
	* @var string
	*/
	private static $vlcLocation = "";
	
	
	/**
	* Set the external IP or hostname for external connections to the VLC Server. The VLC Server will bind on all interfaces on the server
	* You can use port forwarding to enable access from the internet to the internal VLC server.
	* This setting is optional
	* @access private
	* @var string
	*/
	private static $vlcPlayerIP = "";
	
	/**
	* Set the the internal port number for streaming.
	* This setting is required
	* @access private
	* @var string
	*
	*/
	private static $vlcLanStreamPort = 1234;
	
	/**
	*
	* Specify the country codes order for the audio language track.
	* Valid codes: http://nl.wikipedia.org/wiki/Lijst_van_ISO_639-2-codes
	* Or use an integer for selecting the right track.
	* @access private
	* @var string
	*
	*/
	private static $vlcAudioLanguage = "";
	
	private static $vlcSubtitleLanguage = "";

/* MediaInfo configration */

	/**
	* Set the location of the MediaInfo server executable. At least set the value that is corresponding with your 
	* operating system where the PHP code is running. The default settings should be working for 90% of the time.
	*
	* Leave empty to disable the support of MediaInfo. You will lose the duration information on your movies.
	* This setting is optional
	*
	* @access private
	* @var string
	*/
	private static $mediaInfoLocation = "";
	
/* End of settings configuration. You should not edit below this line */

	/**
	* Get the next program from the program guide.
	* @return string
	*/
	static public function getDreamboxName() {
		return trim(Settings::$dreamboxName);
	}
	
	/**
	* Get the program name.
	* @return string
	*/
	static public function getProgramName() {
		return 'Dreambox ReStream';
	}

	/**
	* Get the program version number.
	* @return string
	*/
	static public function getVersionNumber() {
		return trim(Settings::$version);
	}

	/**
	* Get the IP number of the dreambox.
	* @return string
	*/
	static public function getDreamboxIP() {
		return gethostbyname(trim(Settings::$dreamboxIP));
	}
	
	/**
	* Get the port number of the dreambox.
	* @return integer
	*/
	static public function getDreamboxWebPort() {
		return trim(Settings::$dreamboxWebPort);
	}

	/**
	* Get the username of the dreambox.
	* @return string
	*/
	static public function getDreamboxUserName() {
		return trim(Settings::$dreamboxUserName);
	}

	/**
	* Get the password of the dreambox.
	* @return string
	*/
	static public function getDreamboxPassword() {
		return trim(Settings::$dreamboxPassword);
	}

	/**
	* Get the enigma version of the dreambox.
	* @return string
	*/
	static public function getEnigmaVersion() {
		return trim(Settings::$dreamboxEnigmaVersion);
	}

	/**
	* Return true when the dreambox is dual tuner enabled.
	* @return boolean
	*/
	static public function isDualTuner() {
		return (Settings::$dreamboxDualTuner);
	}
	
	/**
	* Return the VLC executable based on OS type.
	* @return string
	*/
	static public function getVLCExecutable() {
		$lVLCExecutable = trim(Settings::$vlcLocation);
		return ($lVLCExecutable != "" && file_exists($lVLCExecutable)? $lVLCExecutable : false);
	}

	/**
	* Get the VLC Server Player IP number.
	* @return string
	*/
	static public function getVLCPlayerIP($pResolve = false) {
		$lIP = trim(Settings::$vlcPlayerIP);
		if ($pResolve) $lIP = gethostbyname($lIP);
		return $lIP;
	}
	
	/**
	* Get the internal streaming port of the VLC Server.
	* @return string
	*/
	static public function getVLCPort() {
		return trim(Settings::$vlcLanStreamPort);
	}
	
	static public function getVLCAudioLanguage() {
		return trim(Settings::$vlcAudioLanguage);
	}
	
	static public function getVLCSubtitleLanguage() {
		return trim(Settings::$vlcSubtitleLanguage);
	}
	static public function getMediaInfoxecutable() {
		$lMediaInfoExecutable = trim(Settings::$mediaInfoLocation);
		return ($lMediaInfoExecutable != "" && file_exists($lMediaInfoExecutable)? $lMediaInfoExecutable : false);
	}

	static public function isPrivate() {
		return (Settings::$privateModus && Settings::getPrivateModusUsername() != "" && Settings::getPrivateModusPassword() != "");
	}

	static public function getPrivateModusUsername() {
		return trim(Settings::$privateModusUsername);
	}

	static public function getPrivateModusPassword() {
		return trim(Settings::$privateModusPassword);
	}

	static public function getMoviesPath() {
		return trim(Settings::$moviesPath);
	}

	static public function getValidMovies() {
		return explode(",",Settings::$validMovies);
	}
	
	static public function getDebug() {
		return (isset($_GET["debug"]) && $_GET["debug"] == 1);
	}
}